Merge "Add sdnc simulator in controlloop-utils"
diff --git a/controlloop/common/feature-controlloop-utils/pom.xml b/controlloop/common/feature-controlloop-utils/pom.xml
index 671f1d1..92b7838 100644
--- a/controlloop/common/feature-controlloop-utils/pom.xml
+++ b/controlloop/common/feature-controlloop-utils/pom.xml
@@ -121,6 +121,11 @@
</dependency>
<dependency>
<groupId>org.onap.policy.drools-applications.controlloop.common.model-impl</groupId>
+ <artifactId>sdnc</artifactId>
+ <version>${project.version}</version>
+ </dependency>
+ <dependency>
+ <groupId>org.onap.policy.drools-applications.controlloop.common.model-impl</groupId>
<artifactId>rest</artifactId>
<version>${project.version}</version>
</dependency>
diff --git a/controlloop/common/feature-controlloop-utils/src/main/feature/config/simulators.properties.environment b/controlloop/common/feature-controlloop-utils/src/main/feature/config/simulators.properties.environment
index cfe957b..c51e8cf 100644
--- a/controlloop/common/feature-controlloop-utils/src/main/feature/config/simulators.properties.environment
+++ b/controlloop/common/feature-controlloop-utils/src/main/feature/config/simulators.properties.environment
@@ -3,6 +3,7 @@
# ONAP
# ================================================================================
# Copyright (C) 2017 AT&T Intellectual Property. All rights reserved.
+# Modifications Copyright (C) 2018 Huawei Intellectual Property. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -35,3 +36,7 @@
guard.url=http://localhost:6669/pdp/api/getDecision
guard.disabled=true
+sdnc.url=http://localhost:6670
+sdnc.username=policy
+sdnc.password=policy
+
diff --git a/controlloop/common/feature-controlloop-utils/src/test/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeatureTest.java b/controlloop/common/feature-controlloop-utils/src/test/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeatureTest.java
index 07b999e..fd73b62 100644
--- a/controlloop/common/feature-controlloop-utils/src/test/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeatureTest.java
+++ b/controlloop/common/feature-controlloop-utils/src/test/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeatureTest.java
@@ -43,6 +43,7 @@
assertNotNull(HttpServletServer.factory.get(Util.SOSIM_SERVER_PORT));
assertNotNull(HttpServletServer.factory.get(Util.SOSIM_SERVER_PORT));
assertNotNull(HttpServletServer.factory.get(Util.GUARDSIM_SERVER_PORT));
+ assertNotNull(HttpServletServer.factory.get(Util.SDNCSIM_SERVER_PORT));
}
}
diff --git a/controlloop/common/feature-controlloop-utils/src/main/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeature.java b/controlloop/common/feature-controlloop-utils/src/main/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeature.java
index 99597f5..8249569 100644
--- a/controlloop/common/feature-controlloop-utils/src/main/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeature.java
+++ b/controlloop/common/feature-controlloop-utils/src/main/java/org/onap/policy/drools/apps/controlloop/feature/utils/ControlLoopUtilsFeature.java
@@ -29,8 +29,8 @@
import org.slf4j.LoggerFactory;
/**
* PDP-D feature for lab environments that provides Server simulation capabilities for AAI, SO, and
* VFC.
*
*/
public class ControlLoopUtilsFeature implements PolicyEngineFeatureAPI {
@@ -44,6 +44,7 @@
Util.buildSoSim();
Util.buildVfcSim();
Util.buildGuardSim();
+ Util.buildSdncSim();
} catch (final InterruptedException e) {
logger.error("{}: initialization aborted", ControlLoopUtilsFeature.class.getName(), e);
Thread.currentThread().interrupt();
@@ -29,8 +29,8 @@
import org.slf4j.LoggerFactory;
/**
- * PDP-D feature for lab environments that provides Server simulation capabilities for AAI, SO, and
- * VFC.
+ * PDP-D feature for lab environments that provides Server simulation capabilities for AAI, SO, SDNC
+ * and VFC.
*
*/